@@ -2,21 +2,25 @@
 #
 #  Pyomo: Python Optimization Modeling Objects
 #  Copyright 2017 National Technology and Engineering Solutions of Sandia, LLC
-#  Under the terms of Contract DE-NA0003525 with National Technology and 
-#  Engineering Solutions of Sandia, LLC, the U.S. Government retains certain 
+#  Under the terms of Contract DE-NA0003525 with National Technology and
+#  Engineering Solutions of Sandia, LLC, the U.S. Government retains certain
 #  rights in this software.
 #  This software is distributed under the 3-clause BSD License.
 #  ___________________________________________________________________________
 
-__all__ = ['ComponentMap','Suffix','active_export_suffix_generator','active_import_suffix_generator']
+__all__ = ('Suffix',
+           'active_export_suffix_generator',
+           'active_import_suffix_generator')
 
 import logging
-from collections import MutableMapping
 import pprint
 
-from pyomo.core.base.component import ActiveComponent, register_component
+from pyomo.core.kernel.component_map import ComponentMap
+from pyomo.core.base.component import (ActiveComponent,
+                                       register_component)
 
 from six import iteritems, itervalues
+from pyomo.util.deprecation import deprecated
 
 logger = logging.getLogger('pyomo.core')
 
@@ -32,7 +36,8 @@ logger = logging.getLogger('pyomo.core')
 #   - active_suffix_generator
 #   - suffix_generator
 
-def active_export_suffix_generator(a_block,datatype=False):
+
+def active_export_suffix_generator(a_block, datatype=False):
     if (datatype is False):
         for name, suffix in iteritems(a_block.component_map(Suffix, active=True)):
             if suffix.export_enabled() is True:
@@ -43,7 +48,8 @@ def active_export_suffix_generator(a_block,datatype=False):
                (suffix.get_datatype() is datatype):
                 yield name, suffix
 
-def export_suffix_generator(a_block,datatype=False):
+
+def export_suffix_generator(a_block, datatype=False):
     if (datatype is False):
         for name, suffix in iteritems(a_block.component_map(Suffix)):
             if suffix.export_enabled() is True:
@@ -54,7 +60,8 @@ def export_suffix_generator(a_block,datatype=False):
                (suffix.get_datatype() is datatype):
                 yield name, suffix
 
-def active_import_suffix_generator(a_block,datatype=False):
+
+def active_import_suffix_generator(a_block, datatype=False):
     if (datatype is False):
         for name, suffix in iteritems(a_block.component_map(Suffix, active=True)):
             if suffix.import_enabled() is True:
@@ -65,7 +72,8 @@ def active_import_suffix_generator(a_block,datatype=False):
                (suffix.get_datatype() is datatype):
                 yield name, suffix
 
-def import_suffix_generator(a_block,datatype=False):
+
+def import_suffix_generator(a_block, datatype=False):
     if (datatype is False):
         for name, suffix in iteritems(a_block.component_map(Suffix)):
             if suffix.import_enabled() is True:
@@ -76,7 +84,8 @@ def import_suffix_generator(a_block,datatype=False):
                (suffix.get_datatype() is datatype):
                 yield name, suffix
 
-def active_local_suffix_generator(a_block,datatype=False):
+
+def active_local_suffix_generator(a_block, datatype=False):
     if (datatype is False):
         for name, suffix in iteritems(a_block.component_map(Suffix, active=True)):
             if suffix.get_direction() is Suffix.LOCAL:
@@ -87,7 +96,8 @@ def active_local_suffix_generator(a_block,datatype=False):
                (suffix.get_datatype() is datatype):
                 yield name, suffix
 
-def local_suffix_generator(a_block,datatype=False):
+
+def local_suffix_generator(a_block, datatype=False):
     if (datatype is False):
         for name, suffix in iteritems(a_block.component_map(Suffix)):
             if suffix.get_direction() is Suffix.LOCAL:
@@ -98,7 +108,8 @@ def local_suffix_generator(a_block,datatype=False):
                (suffix.get_datatype() is datatype):
                 yield name, suffix
 
-def active_suffix_generator(a_block,datatype=False):
+
+def active_suffix_generator(a_block, datatype=False):
     if (datatype is False):
         for name, suffix in iteritems(a_block.component_map(Suffix, active=True)):
             yield name, suffix
@@ -107,7 +118,8 @@ def active_suffix_generator(a_block,datatype=False):
             if suffix.get_datatype() is datatype:
                 yield name, suffix
 
-def suffix_generator(a_block,datatype=False):
+
+def suffix_generator(a_block, datatype=False):
     if (datatype is False):
         for name, suffix in iteritems(a_block.component_map(Suffix)):
             yield name, suffix
@@ -116,152 +128,12 @@ def suffix_generator(a_block,datatype=False):
             if suffix.get_datatype() is datatype:
                 yield name, suffix
 
-#
-# This class acts as replacement for dict that allows Pyomo modeling
-# components (and anything else) to be used as entry keys. The
-# underlying mapping is based on the Python id() of the object, so
-# that hashing can still take place when the object is mutable,
-# unhashable, etc.
-#
-# A reference to the object is kept around as long as it has a
-# corresponding entry in the container so that we don't need to worry
-# about id() clashes.
-#
-# We also override __setstate__ so that we can rebuild the container
-# based on possibly updated object id()'s after a deepcopy or
-# unpickle.
-#
-# *** An instance of this class should never be deepcopied/pickled
-# unless it is done so along with the components for which it contains
-# map entries. ***
-#
-
-class ComponentMap(MutableMapping):
-
-    def __init__(self, *args, **kwds):
-
-        # maps id(obj) -> (obj,val)
-        self._dict = {}
-        # handle the dict-style initialization scenarios
-        self.update(*args, **kwds)
-
-    def __setstate__(self, state):
-        """
-        This method must be defined for deepcopy/pickling because this
-        class relies on Python ids.
-        """
-        id_func = id
-        # object id() may have changed after unpickling so we rebuild
-        # the dictionary keys
-        self._dict = \
-            dict((id_func(component), (component,val)) \
-                 for component, val in itervalues(state['_dict']))
-
-    def __str__(self):
-        """
-        String representation of the mapping
-        """
-        tmp = '{' + \
-              (', '.join(component.name+": "+str(val) \
-                        for component, val \
-                        in itervalues(self._dict))) + \
-              '}'
-        return tmp
-
-    def pprint(self, stream=None, indent=1, width=80, depth=None, verbose=False):
-        """
-        Pretty-print a Python object to a stream [default is sys.stdout].
-        """
-        if verbose:
-            tmp = dict((repr(component.name)+" (id="+str(id(component))+")", val)
-                           for component, val \
-                           in itervalues(self._dict))
-        else:
-            tmp = dict((repr(component.name)+" (id="+str(id(component))+")", val)
-                           for component, val \
-                           in itervalues(self._dict))
-        pprint.pprint(tmp,
-                      stream=stream,
-                      indent=indent,
-                      width=width,
-                      depth=depth)
-
-    #
-    # MutableMapping Abstract Methods
-    #
-
-    def __getitem__(self, component):
-        try:
-            return self._dict[id(component)][1]
-        except KeyError:
-            cname = component.name
-            raise KeyError("Component with name: "
-                           +cname+
-                           " (id=%s)" % id(component))
-
-    def __setitem__(self, component, value):
-        self._dict[id(component)] = (component,value)
-
-    def __delitem__(self, component):
-        try:
-            del self._dict[id(component)]
-        except KeyError:
-            cname = component.name
-            raise KeyError("Component with name: "
-                           +cname+
-                           " (id=%s)" % id(component))
-
-    def __iter__(self):
-        return (component \
-                for component, value in \
-                itervalues(self._dict))
-
-    def __len__(self):
-        return self._dict.__len__()
-
-    #
-    # Overload MutableMapping default implementations
-    #
-
-    def __eq__(self, other):
-        raise NotImplementedError("ComponentMap is not comparable")
-
-    def __ne__(self, other):
-        raise NotImplementedError("ComponentMap is not comparable")
-
-    #
-    # The remaining methods have slow default implementations
-    # for MutableMapping. In particular, they rely KeyError
-    # catching, which is slow for this class because KeyError
-    # messages use fully qualified names.
-    #
-
-    def __contains__(self, component):
-        return id(component) in self._dict
-
-    def clear(self):
-        'D.clear() -> None.  Remove all items from D.'
-        self._dict.clear()
-
-    def get(self, key, default=None):
-        'D.get(k[,d]) -> D[k] if k in D, else d.  d defaults to None.'
-        if key in self:
-            return self[key]
-        return default
-
-    def setdefault(self, key, default=None):
-        'D.setdefault(k[,d]) -> D.get(k,d), also set D[k]=d if k not in D'
-        if key in self:
-            return self[key]
-        else:
-            self[key] = default
-        return default
-
-
 # Note: The order of inheritance here is important so that
 #       __setstate__ works correctly on the ActiveComponent base class.
+
+
 class Suffix(ComponentMap, ActiveComponent):
-    """A model suffix, representing extranious model data"""
+    """A model suffix, representing extraneous model data"""
 
     """
     Constructor Arguments:
@@ -276,25 +148,25 @@ class Suffix(ComponentMap, ActiveComponent):
     # If more directions are added be sure to update the error message
     # in the setDirection method
     # neither sent to solver or received from solver
-    LOCAL  = 0
+    LOCAL = 0
     # sent to solver or other external location
     EXPORT = 1
     # obtained from solver or other external source
     IMPORT = 2
-    IMPORT_EXPORT = 3 # both
+    IMPORT_EXPORT = 3  # both
 
-    SuffixDirections = (LOCAL,EXPORT,IMPORT,IMPORT_EXPORT)
-    SuffixDirectionToStr = {LOCAL:'Suffix.LOCAL',
-                            EXPORT:'Suffix.EXPORT',
-                            IMPORT:'Suffix.IMPORT',
-                            IMPORT_EXPORT:'Suffix.IMPORT_EXPORT'}
+    SuffixDirections = (LOCAL, EXPORT, IMPORT, IMPORT_EXPORT)
+    SuffixDirectionToStr = {LOCAL: 'Suffix.LOCAL',
+                            EXPORT: 'Suffix.EXPORT',
+                            IMPORT: 'Suffix.IMPORT',
+                            IMPORT_EXPORT: 'Suffix.IMPORT_EXPORT'}
     # Suffix Datatypes
     FLOAT = 4
     INT = 0
-    SuffixDatatypes = (FLOAT,INT,None)
-    SuffixDatatypeToStr = {FLOAT:'Suffix.FLOAT',
-                           INT:'Suffix.INT',
-                           None:str(None)}
+    SuffixDatatypes = (FLOAT, INT, None)
+    SuffixDatatypeToStr = {FLOAT: 'Suffix.FLOAT',
+                           INT: 'Suffix.INT',
+                           None: str(None)}
 
     def __init__(self, **kwds):
 
@@ -304,15 +176,15 @@ class Suffix(ComponentMap, ActiveComponent):
         self._rule = None
 
         # The suffix direction
-        direction = kwds.pop('direction',Suffix.LOCAL)
+        direction = kwds.pop('direction', Suffix.LOCAL)
 
         # The suffix datatype
-        datatype = kwds.pop('datatype',Suffix.FLOAT)
+        datatype = kwds.pop('datatype', Suffix.FLOAT)
 
         # The suffix construction rule
         # TODO: deprecate the use of 'rule'
-        self._rule = kwds.pop('rule',None)
-        self._rule = kwds.pop('initialize',self._rule)
+        self._rule = kwds.pop('rule', None)
+        self._rule = kwds.pop('initialize', self._rule)
 
         # Check that keyword values make sense (these function have
         # internal error checking).
@@ -332,15 +204,15 @@ class Suffix(ComponentMap, ActiveComponent):
         This method must be defined for deepcopy/pickling because this
         class relies on component ids.
         """
-        ActiveComponent.__setstate__(self,state)
-        ComponentMap.__setstate__(self,state)
+        ActiveComponent.__setstate__(self, state)
+        ComponentMap.__setstate__(self, state)
 
     def construct(self, data=None):
         """
         Constructs this component, applying rule if it exists.
         """
         if __debug__ and logger.isEnabledFor(logging.DEBUG):
-            logger.debug("Constructing suffix %s",self.name)
+            logger.debug("Constructing suffix %s", self.name)
 
         if self._constructed is True:
             return
@@ -350,9 +222,8 @@ class Suffix(ComponentMap, ActiveComponent):
         if self._rule is not None:
             self.update_values(self._rule(self._parent()))
 
+    @deprecated('Suffix.exportEnabled is replaced with Suffix.export_enabled.')
     def exportEnabled(self):
-        logger.warning("DEPRECATION WARNING: Suffix.exportEnabled is replaced "
-                       " with Suffix.export_enabled.")
         return self.export_enabled()
 
     def export_enabled(self):
@@ -362,9 +233,8 @@ class Suffix(ComponentMap, ActiveComponent):
         """
         return bool(self._direction & Suffix.EXPORT)
 
+    @deprecated('Suffix.importEnabled is replaced with Suffix.import_enabled.')
     def importEnabled(self):
-        logger.warning("DEPRECATION WARNING: Suffix.importEnabled is replaced "
-                       " with Suffix.import_enabled.")
         return self.import_enabled()
 
     def import_enabled(self):
@@ -374,10 +244,9 @@ class Suffix(ComponentMap, ActiveComponent):
         """
         return bool(self._direction & Suffix.IMPORT)
 
+    @deprecated('Suffix.updateValues is replaced with Suffix.update_values.')
     def updateValues(self, data, expand=True):
-        logger.warning("DEPRECATION WARNING: Suffix.updateValues is replaced "
-                       " with Suffix.update_values.")
-        return self.update_values(data,expand)
+        return self.update_values(data, expand)
 
     def update_values(self, data, expand=True):
         """
@@ -400,9 +269,8 @@ class Suffix(ComponentMap, ActiveComponent):
             # As implemented by MutableMapping
             self.update(data)
 
+    @deprecated('Suffix.setValue is replaced with Suffix.set_value.')
     def setValue(self, component, value, expand=True):
-        logger.warning("DEPRECATION WARNING: Suffix.setValue is replaced "
-                       " with Suffix.set_value.")
         return self.set_value(component, value, expand)
 
     def set_value(self, component, value, expand=True):
@@ -422,9 +290,8 @@ class Suffix(ComponentMap, ActiveComponent):
         else:
             self[component] = value
 
+    @deprecated('Suffix.setAllValues is replaced with Suffix.set_all_values.')
     def setAllValues(self, value):
-        logger.warning("DEPRECATION WARNING: Suffix.setAllValues is replaced "
-                       " with Suffix.set_all_values.")
         return self.set_all_values(value)
 
     def set_all_values(self, value):
@@ -434,9 +301,8 @@ class Suffix(ComponentMap, ActiveComponent):
         for ndx in self:
             self[ndx] = value
 
+    @deprecated('Suffix.clearValue is replaced with Suffix.clear_value.')
     def clearValue(self, component, expand=True):
-        logger.warning("DEPRECATION WARNING: Suffix.clearValue is replaced "
-                       " with Suffix.clear_value.")
         return self.clear_value(component, expand)
 
     def clear_value(self, component, expand=True):
@@ -455,9 +321,9 @@ class Suffix(ComponentMap, ActiveComponent):
             except KeyError:
                 pass
 
+    @deprecated('Suffix.clearAllValues is replaced with '
+                'Suffix.clear_all_values.')
     def clearAllValues(self):
-        logger.warning("DEPRECATION WARNING: Suffix.clearAllValues is replaced "
-                       " with Suffix.clear_all_values.")
         return self.clear_all_values()
 
     def clear_all_values(self):
@@ -466,9 +332,8 @@ class Suffix(ComponentMap, ActiveComponent):
         """
         self.clear()
 
+    @deprecated('Suffix.setDatatype is replaced with Suffix.set_datatype.')
     def setDatatype(self, datatype):
-        logger.warning("DEPRECATION WARNING: Suffix.setDatatype is replaced "
-                       " with Suffix.set_datatype.")
         return self.set_datatype(datatype)
 
     def set_datatype(self, datatype):
@@ -477,14 +342,13 @@ class Suffix(ComponentMap, ActiveComponent):
         """
         if datatype not in self.SuffixDatatypes:
             raise ValueError("Suffix datatype must be one of: %s. \n"
-                              "Value given: %s"
+                             "Value given: %s"
                              % (list(Suffix.SuffixDatatypeToStr.values()),
                                 datatype))
         self._datatype = datatype
 
+    @deprecated('Suffix.getDatatype is replaced with Suffix.get_datatype.')
     def getDatatype(self):
-        logger.warning("DEPRECATION WARNING: Suffix.getDatatype is replaced "
-                       " with Suffix.get_datatype.")
         return self.get_datatype()
 
     def get_datatype(self):
@@ -493,25 +357,23 @@ class Suffix(ComponentMap, ActiveComponent):
         """
         return self._datatype
 
+    @deprecated('Suffix.setDirection is replaced with Suffix.set_direction.')
     def setDirection(self, direction):
-        logger.warning("DEPRECATION WARNING: Suffix.setDirection is replaced "
-                       " with Suffix.set_direction.")
         return self.set_direction(direction)
 
     def set_direction(self, direction):
         """
         Set the suffix direction.
         """
-        if not direction in self.SuffixDirections:
+        if direction not in self.SuffixDirections:
             raise ValueError("Suffix direction must be one of: %s. \n"
-                              "Value given: %s"
+                             "Value given: %s"
                              % (list(self.SuffixDirectionToStr.values()),
                                 direction))
         self._direction = direction
 
+    @deprecated('Suffix.getDirection is replaced with Suffix.get_direction.')
     def getDirection(self):
-        logger.warning("DEPRECATION WARNING: Suffix.getDirection is replaced "
-                       " with Suffix.get_direction.")
         return self.get_direction()
 
     def get_direction(self):
@@ -535,30 +397,30 @@ class Suffix(ComponentMap, ActiveComponent):
             [('Direction', self.SuffixDirectionToStr[self._direction]),
              ('Datatype', self.SuffixDatatypeToStr[self._datatype]),
              ],
-            ( (str(k),v) for k,v in itervalues(self._dict) ),
+            ((str(k), v) for k, v in itervalues(self._dict)),
             ("Value",),
-            lambda k,v: [ v ]
-            )
+            lambda k, v: [v]
+        )
 
     # TODO: delete
+    @deprecated('Suffix.getValue is replaced with '
+                'the dict-interface method Suffix.get.')
     def getValue(self, component, *args):
         """
         Returns the current value of this suffix for the specified
         component.
         """
-        logger.warning("DEPRECATION WARNING: Suffix.getValue is replaced "
-                       " with the dict-interface method Suffix.get.")
         # As implemented by MutableMapping
         return self.get(component, *args)
 
     # TODO: delete
+    @deprecated('Suffix.extractValues() is replaced with '
+                'the dict-interface method Suffix.items().')
     def extractValues(self):
         """
         Extract all data stored on this Suffix into a list of
         component, value tuples.
         """
-        logger.warning("DEPRECATION WARNING: Suffix.extractValues() is replaced "
-                       " with the dict-interface method Suffix.items().")
         # As implemented by MutableMapping
         return list(self.items())
 
@@ -579,9 +441,11 @@ class Suffix(ComponentMap, ActiveComponent):
     #
 
     def __eq__(self, other):
+        """Not implemented."""
         raise NotImplementedError("Suffix components are not comparable")
 
     def __ne__(self, other):
+        """Not implemented."""
         raise NotImplementedError("Suffix components are not comparable")
 
 
