@@ -2,8 +2,8 @@
 #
 #  Pyomo: Python Optimization Modeling Objects
 #  Copyright 2017 National Technology and Engineering Solutions of Sandia, LLC
-#  Under the terms of Contract DE-NA0003525 with National Technology and 
-#  Engineering Solutions of Sandia, LLC, the U.S. Government retains certain 
+#  Under the terms of Contract DE-NA0003525 with National Technology and
+#  Engineering Solutions of Sandia, LLC, the U.S. Government retains certain
 #  rights in this software.
 #  This software is distributed under the 3-clause BSD License.
 #  ___________________________________________________________________________
@@ -34,7 +34,8 @@ try:
     _operatorMap = {
         sympy.Add: _sum,
         sympy.Mul: _prod,
-        sympy.Pow: lambda x,y: x**y,
+        sympy.Pow: lambda x, y: x**y,
+        sympy.exp: lambda x: core.exp(x),
         sympy.log: lambda x: core.log(x),
         sympy.sin: lambda x: core.sin(x),
         sympy.asin: lambda x: core.asin(x),
@@ -62,6 +63,21 @@ class NondifferentiableError(ValueError):
 
 
 def differentiate(expr, wrt=None, wrt_list=None):
+    """Return derivative of expression.
+
+    This function returns an expression or list of expression objects
+    corresponding to the derivative of the passed expression 'expr' with
+    respect to a variable 'wrt' or list of variables 'wrt_list'
+
+    Args:
+        expr (Expression): Pyomo expression
+        wrt (Var): Pyomo variable
+        wrt_list (list): list of Pyomo variables
+
+    Returns:
+        Expression or list of Expression objects
+
+    """
     if not _sympy_available:
         raise RuntimeError(
             "The sympy module is not available.  "
