@@ -93,7 +93,7 @@ class IndexTemplate(NumericValue):
     def getname(self, fully_qualified=False, name_buffer=None):
         return "{"+self._set.getname(fully_qualified, name_buffer)+"}"
 
-    def to_string(self, ostream=None, verbose=None, precedence=0):
+    def to_string(self, ostream=None, verbose=None, precedence=0, labeler=None):
         if ostream is None:
             ostream = sys.stdout
         ostream.write( self.name )
@@ -213,6 +213,10 @@ class _GetItemIndexer(object):
         else:
             return False
 
+    def __str__(self):
+        return "%s[%s]" % (
+            self._base.name, ','.join(str(x) for x in self._args) )
+
 def substitute_getitem_with_param(expr, _map):
     """A simple substituter to replace _GetItem nodes with mutable Params.
 
