@@ -8,13 +8,6 @@
 #  This software is distributed under the 3-clause BSD License.
 #  ___________________________________________________________________________
 
-#
-# Expose the symbols from pyomo.core
-#
-from pyomo.core import *
-from pyomo.opt import SolverFactory, SolverManagerFactory, UnknownSolver
-from pyomo.util.plugin import PluginGlobals as _PG
-
 import sys as _sys
 if _sys.version_info[0] >= 3:
     import importlib
@@ -28,10 +21,22 @@ else:
 #
 # These packages contain plugins that need to be loaded
 #
-_packages = ['pyomo.opt', 'pyomo.core', 'pyomo.checker', 'pyomo.repn',
-             'pyomo.pysp', 'pyomo.neos',
-             'pyomo.solvers', 'pyomo.gdp', 'pyomo.mpec',
-             'pyomo.dae', 'pyomo.bilevel', 'pyomo.scripting']
+_packages = [
+    'pyomo.opt',
+    'pyomo.core',
+    'pyomo.checker',
+    'pyomo.repn',
+    'pyomo.pysp',
+    'pyomo.neos',
+    'pyomo.solvers',
+    'pyomo.gdp',
+    'pyomo.mpec',
+    'pyomo.dae',
+    'pyomo.bilevel',
+    'pyomo.scripting',
+]
+#_packages = [ _packages[int(_sys.argv[1])] ]
+#_sys.stdout.write("%s  " % _packages[0])
 #
 # These packages are under development, or they may be omitted in a
 # Pyomo installation; silently ignore any import errors.
@@ -67,6 +72,13 @@ def _import_packages():
         pkg = _sys.modules[pname]
         pkg.load()
 
+from pyomo.util.plugin import PluginGlobals as _PG
 _PG.add_env("pyomo")
 _import_packages()
 _PG.pop_env()
+
+#
+# Expose the symbols from pyomo.core
+#
+from pyomo.core import *
+from pyomo.opt import SolverFactory, SolverManagerFactory, UnknownSolver
