@@ -38,7 +38,6 @@ from six.moves import xrange
 
 logger = logging.getLogger('pyomo.opt')
 
-
 # The version string is first searched for trunk/Trunk, and if
 # found a tuple of infinities is returned. Otherwise, the first
 # match of number[.number] where [.number] can repeat 1-3 times
@@ -451,7 +450,7 @@ class OptSolver(Plugin):
 
     def version(self):
         """
-        Returns a tuple describing the solver executable version.
+        Returns a 4-tuple describing the solver executable version.
         """
         if self._version is None:
             self._version = self._get_version()
@@ -542,18 +541,33 @@ class OptSolver(Plugin):
         # constructed! Collect suffix names to try and import from solution.
         #
         from pyomo.core.base.block import _BlockData
-        from pyomo.core.base.suffix import active_import_suffix_generator
+        import pyomo.core.base.suffix
+        from pyomo.core.kernel.component_block import IBlockStorage
+        import pyomo.core.kernel.component_suffix
         _model = None
         for arg in args:
-            if isinstance(arg, _BlockData):
-                if not arg.is_constructed():
-                    raise RuntimeError(
-                        "Attempting to solve model=%s with unconstructed "
-                        "component(s)" % (arg.name,) )
+            if isinstance(arg, (_BlockData, IBlockStorage)):
+                if isinstance(arg, _BlockData):
+                    if not arg.is_constructed():
+                        raise RuntimeError(
+                            "Attempting to solve model=%s with unconstructed "
+                            "component(s)" % (arg.name,) )
+
                 _model = arg
+                # import suffixes must be on the top-level model
+                if isinstance(arg, _BlockData):
+                    model_suffixes = list(name for (name,comp) \
+                                          in pyomo.core.base.suffix.\
+                                          active_import_suffix_generator(arg))
+                else:
+                    assert isinstance(arg, IBlockStorage)
+                    model_suffixes = list(name for (name,comp) \
+                                          in pyomo.core.kernel.component_suffix.\
+                                          import_suffix_generator(arg,
+                                                                  active=True,
+                                                                  descend_into=False,
+                                                                  return_key=True))
 
-                model_suffixes = list(name for (name,comp) \
-                                      in active_import_suffix_generator(arg))
                 if len(model_suffixes) > 0:
                     kwds_suffixes = kwds.setdefault('suffixes',[])
                     for name in model_suffixes:
@@ -582,6 +596,8 @@ class OptSolver(Plugin):
             self._presolve(*args, **kwds)
 
             presolve_completion_time = time.time()
+            if self._report_timing:
+                print("      %6.2f seconds required for presolve" % (presolve_completion_time - initial_time))
 
             if not _model is None:
                 self._initialize_callbacks(_model)
@@ -606,30 +622,45 @@ class OptSolver(Plugin):
                 raise pyutilib.common.ApplicationError(
                     "Solver (%s) did not exit normally" % self.name)
             solve_completion_time = time.time()
+            if self._report_timing:
+                print("      %6.2f seconds required for solver" % (solve_completion_time - presolve_completion_time))
 
             result = self._postsolve()
             result._smap_id = self._smap_id
             result._smap = None
             if _model:
-                if self._load_solutions:
-                    _model.solutions.load_from(
-                        result,
-                        select=self._select_index,
-                        default_variable_value=self._default_variable_value)
-                    result._smap_id = None
-                    result.solution.clear()
+                if isinstance(_model, IBlockStorage):
+                    if len(result.solution) == 1:
+                        result.solution(0).symbol_map = \
+                            getattr(_model, "._symbol_maps")[result._smap_id]
+                        result.solution(0).default_variable_value = \
+                            self._default_variable_value
+                        if self._load_solutions:
+                            _model.load_solution(result.solution(0))
+                            result.solution.clear()
+                    else:
+                        assert len(result.solution) == 0
+                    # see the hack in the write method
+                    # we don't want this to stick around on the model
+                    # after the solve
+                    assert len(getattr(_model, "._symbol_maps")) == 1
+                    delattr(_model, "._symbol_maps")
+                    del result._smap_id
                 else:
-                    result._smap = _model.solutions.symbol_map[self._smap_id]
-                    _model.solutions.delete_symbol_map(self._smap_id)
+                    if self._load_solutions:
+                        _model.solutions.load_from(
+                            result,
+                            select=self._select_index,
+                            default_variable_value=self._default_variable_value)
+                        result._smap_id = None
+                        result.solution.clear()
+                    else:
+                        result._smap = _model.solutions.symbol_map[self._smap_id]
+                        _model.solutions.delete_symbol_map(self._smap_id)
             postsolve_completion_time = time.time()
 
             if self._report_timing:
-                print("Presolve time=%0.2f seconds"
-                      % (presolve_completion_time - initial_time))
-                print("Solve time=%0.2f seconds"
-                      % (solve_completion_time - presolve_completion_time))
-                print("Postsolve time=%0.2f seconds"
-                      % (postsolve_completion_time - solve_completion_time))
+                print("      %6.2f seconds required for postsolve" % (postsolve_completion_time - solve_completion_time))
 
         finally:
             #
@@ -654,11 +685,15 @@ class OptSolver(Plugin):
         self.available()
 
         if self._problem_format:
+            write_start_time = time.time()
             (self._problem_files, self._problem_format, self._smap_id) = \
                 self._convert_problem(args,
                                       self._problem_format,
                                       self._valid_problem_formats,
                                       **kwds)
+            total_time = time.time() - write_start_time
+            if self._report_timing:
+                print("      %6.2f seconds required to write file" % total_time)
         else:
             if len(kwds):
                 raise ValueError(
