@@ -461,13 +461,14 @@ def _get_test_dispatcher(ns_host=None,
             dispatcher_port = find_unused_port()
             print("Trying dispatcher with port: "
                   +str(dispatcher_port))
+            cmd = ["dispatch_srvr",
+                   "--host="+str(ns_host),
+                   "--port="+str(ns_port),
+                   "--daemon-host="+str(dispatcher_host),
+                   "--daemon-port="+str(dispatcher_port)]
+            print(' '.join(cmd))
             dispatcher_process = \
-                subprocess.Popen(["dispatch_srvr"] + \
-                                 ["--host="+str(ns_host)] + \
-                                 ["--port="+str(ns_port)] + \
-                                 ["--daemon-host="+str(dispatcher_host)] + \
-                                 ["--daemon-port="+str(dispatcher_port)],
-                                 stdout=subprocess.PIPE)
+                subprocess.Popen(cmd, stdout=subprocess.PIPE)
             time.sleep(5)
             _poll(dispatcher_process)
             break
