@@ -2,8 +2,8 @@
 #
 #  Pyomo: Python Optimization Modeling Objects
 #  Copyright 2017 National Technology and Engineering Solutions of Sandia, LLC
-#  Under the terms of Contract DE-NA0003525 with National Technology and 
-#  Engineering Solutions of Sandia, LLC, the U.S. Government retains certain 
+#  Under the terms of Contract DE-NA0003525 with National Technology and
+#  Engineering Solutions of Sandia, LLC, the U.S. Government retains certain
 #  rights in this software.
 #  This software is distributed under the 3-clause BSD License.
 #  ___________________________________________________________________________
@@ -169,5 +169,75 @@ class TestCPXLPOrdering(unittest.TestCase):
         row_order[model.con4[2]] = -1
         self._check_baseline(model, row_order=row_order)
 
+class TestCPXLP_writer(unittest.TestCase):
+
+    def _cleanup(self, fname):
+        try:
+            os.remove(fname)
+        except OSError:
+            pass
+
+    def _get_fnames(self):
+        class_name, test_name = self.id().split('.')[-2:]
+        prefix = os.path.join(thisdir, test_name.replace("test_", "", 1))
+        return prefix+".lp.baseline", prefix+".lp.out"
+
+    def test_var_on_other_model(self):
+        other = ConcreteModel()
+        other.a = Var()
+
+        model = ConcreteModel()
+        model.x = Var()
+        model.c = Constraint(expr=other.a + 2*model.x <= 0)
+        model.obj = Objective(expr=model.x)
+
+        baseline_fname, test_fname = self._get_fnames()
+        self._cleanup(test_fname)
+        self.assertRaisesRegexp(
+            KeyError,
+            "'a' is not part of the model",
+            model.write, test_fname, format='lp')
+        self._cleanup(test_fname)
+
+    def test_var_on_deactivated_block(self):
+        model = ConcreteModel()
+        model.x = Var()
+        model.other = Block()
+        model.other.a = Var()
+        model.other.deactivate()
+        model.c = Constraint(expr=model.other.a + 2*model.x <= 0)
+        model.obj = Objective(expr=model.x)
+
+        baseline_fname, test_fname = self._get_fnames()
+        self._cleanup(test_fname)
+        self.assertRaisesRegexp(
+            KeyError,
+            "'other.a' exists within deactivated Block 'other'",
+            model.write, test_fname, format='lp' )
+        self._cleanup(test_fname)
+
+    def test_var_on_nonblock(self):
+        class Foo(Block().__class__):
+            def __init__(self, *args, **kwds):
+                kwds.setdefault('ctype',Foo)
+                super(Foo,self).__init__(*args, **kwds)
+
+        model = ConcreteModel()
+        model.x = Var()
+        model.other = Foo()
+        model.other.a = Var()
+        model.c = Constraint(expr=model.other.a + 2*model.x <= 0)
+        model.obj = Objective(expr=model.x)
+
+        baseline_fname, test_fname = self._get_fnames()
+        self._cleanup(test_fname)
+        self.assertRaisesRegexp(
+            KeyError,
+            "'other.a' exists within Foo 'other'",
+            model.write, test_fname, format='lp')
+        self._cleanup(test_fname)
+
+
+
 if __name__ == "__main__":
     unittest.main()
