@@ -271,9 +271,11 @@ def create_model(data):
     # Find the Model objects
     #
     _models = {}
+    _model_IDS = set()
     for _name, _obj in iteritems(data.local.usermodel.__dict__):
-        if isinstance(_obj, Model):
+        if isinstance(_obj, Model) and id(_obj) not in _model_IDS:
             _models[_name] = _obj
+            _model_IDS.add(id(_obj))
     model_name = data.options.model.object_name
     if len(_models) == 1:
         _name  = list(_models.keys())[0]
@@ -302,7 +304,11 @@ def create_model(data):
             raise SystemExit(msg % data.options.model.filename)
         else:
             model_options = data.options.model.options.value()
+            tick = time.time()
             model = ep.service().apply( options = pyutilib.misc.Container(*data.options), model_options=pyutilib.misc.Container(*model_options) )
+            if data.options.runtime.report_timing is True:
+                print("      %6.2f seconds required to construct instance" % (time.time() - tick))
+                tick = time.time()
     else:
         if model_name not in _models:
             msg = "Model '%s' is not defined in file '%s'!"
@@ -580,15 +586,24 @@ def apply_optimizer(data, instance=None):
             keywords['file_determinism'] = data.options.model.file_determinism
         keywords['tee'] = data.options.runtime.stream_output
         keywords['timelimit'] = getattr(data.options.solvers[0].options, 'timelimit', 0)
+        keywords['report_timing'] = data.options.runtime.report_timing
+
+        # FIXME: solver_io and executable are not being used
+        #        in the case of a non-serial solver manager
+
         #
         # Call the solver
         #
         if solver_mngr_name == 'serial':
             #
-            # If we're running locally, then we create the optimizer and pass it into the 
-            # solver manager.
+            # If we're running locally, then we create the
+            # optimizer and pass it into the solver manager.
             #
-            with SolverFactory(solver, solver_io=data.options.solvers[0].io_format) as opt:
+            sf_kwds = {}
+            sf_kwds['solver_io'] = data.options.solvers[0].io_format
+            if data.options.solvers[0].solver_executable is not None:
+                sf_kwds['executable'] = data.options.solvers[0].solver_executable
+            with SolverFactory(solver, **sf_kwds) as opt:
                 if opt is None:
                     raise ValueError("Problem constructing solver `%s`" % str(solver))
 
@@ -846,14 +861,18 @@ def configure_loggers(options=None, reset=False):
         logging.getLogger('pyomo.core').setLevel(logging.DEBUG)
         logging.getLogger('pyomo').setLevel(logging.DEBUG)
         logging.getLogger('pyutilib').setLevel(logging.DEBUG)
+
+    fileLogger = None
     if options.runtime.logfile:
+        fileLogger = logging.FileHandler(options.runtime.logfile, 'w')
         logging.getLogger('pyomo.opt').handlers = []
         logging.getLogger('pyomo.core').handlers = []
         logging.getLogger('pyomo').handlers = []
         logging.getLogger('pyutilib').handlers = []
-        logging.getLogger('pyomo.core').addHandler( logging.FileHandler(options.runtime.logfile, 'w'))
-        logging.getLogger('pyomo').addHandler( logging.FileHandler(options.runtime.logfile, 'w'))
-        logging.getLogger('pyutilib').addHandler( logging.FileHandler(options.runtime.logfile, 'w'))
+        logging.getLogger('pyomo.core').addHandler(fileLogger)
+        logging.getLogger('pyomo').addHandler(fileLogger)
+        logging.getLogger('pyutilib').addHandler(fileLogger)
+    return fileLogger
 
 @pyomo_api(namespace='pyomo.script')
 def run_command(command=None, parser=None, args=None, name='unknown', data=None, options=None):
@@ -909,13 +928,14 @@ def run_command(command=None, parser=None, args=None, name='unknown', data=None,
     #
     # Configure loggers
     #
-    configure_loggers(options=options)
+    fileLogger = configure_loggers(options=options)
     #
     # Setup I/O redirect to a file
     #
-    logfile = options.runtime.logfile
-    if not logfile is None:
-        pyutilib.misc.setup_redirect(logfile)
+    if fileLogger is not None:
+        # TBD: This seems dangerous in Windows, as the process will
+        # have multiple open file handles pointint to the same file.
+        pyutilib.misc.setup_redirect(options.runtime.logfile)
     #
     # Call the main Pyomo runner with profiling
     #
@@ -923,10 +943,12 @@ def run_command(command=None, parser=None, args=None, name='unknown', data=None,
     pcount = options.runtime.profile_count
     if pcount > 0:
         if not pstats_available:
-            if not logfile is None:
-                pyutilib.misc.reset_redirect()
             msg = "Cannot use the 'profile' option.  The Python 'pstats' "    \
                   'package cannot be imported!'
+            if fileLogger is not None:
+                pyutilib.misc.reset_redirect()
+                fileLogger.close()
+                configure_loggers(options=Options(), reset=True)
             raise ValueError(msg)
         tfile = TempfileManager.create_tempfile(suffix=".profile")
         tmp = profile.runctx(
@@ -960,6 +982,10 @@ def run_command(command=None, parser=None, args=None, name='unknown', data=None,
             # exit.  Otherwise, print an "Exiting..." message.
             #
             if __debug__ and (options.runtime.logging == 'debug' or options.runtime.catch_errors):
+                if fileLogger is not None:
+                    pyutilib.misc.reset_redirect()
+                    fileLogger.close()
+                    configure_loggers(options=Options(), reset=True)
                 sys.exit(0)
             print('Exiting %s: %s' % (name, str(err)))
             errorcode = err.code
@@ -970,8 +996,10 @@ def run_command(command=None, parser=None, args=None, name='unknown', data=None,
             # pass the exception up the chain (to pyomo_excepthook)
             #
             if __debug__ and (options.runtime.logging == 'debug' or options.runtime.catch_errors):
-                if not logfile is None:
+                if fileLogger is not None:
                     pyutilib.misc.reset_redirect()
+                    fileLogger.close()
+                    configure_loggers(options=Options(), reset=True)
                 TempfileManager.pop(remove=not options.runtime.keep_files)
                 raise
 
@@ -1000,8 +1028,10 @@ def run_command(command=None, parser=None, args=None, name='unknown', data=None,
             logging.getLogger('pyomo.core').error(msg+errStr)
             errorcode = 1
 
-    if not logfile is None:
+    if fileLogger is not None:
         pyutilib.misc.reset_redirect()
+        fileLogger.close()
+        configure_loggers(options=Options(), reset=True)
 
     if options.runtime.disable_gc:
         gc.enable()
