@@ -19,7 +19,6 @@ import math
 
 import pyutilib.services
 from pyutilib.misc import Bunch, Options
-from pyutilib.math import infinity
 
 import pyomo.util.plugin
 from pyomo.opt.base import *
@@ -35,6 +34,8 @@ from pyomo.core.base import (SymbolMap,
 from pyomo.repn import generate_canonical_repn
 from pyomo.solvers import wrappers
 
+from pyomo.core.kernel.component_block import IBlockStorage
+
 from six import itervalues, iterkeys, iteritems, advance_iterator
 from six.moves import xrange
 
@@ -92,7 +93,10 @@ class ModelSOS(object):
 
     def count_constraint(self,symbol_map,labeler,variable_symbol_map,soscondata):
 
-        sos_items = list(soscondata.get_items())
+        if hasattr(soscondata, 'get_items'):
+            sos_items = list(soscondata.get_items())
+        else:
+            sos_items = list(soscondata.items())
         level = soscondata.level
 
         if len(sos_items) == 0:
@@ -260,7 +264,8 @@ class CPLEXDirect(OptSolver):
 
         self_variable_symbol_map = self._variable_symbol_map
 
-        if variables != None:
+        if (variables is not None) and \
+           (len(variables) > 0):
 
             for var_value, var_coefficient in zip(variables, coefficients):
 
@@ -371,8 +376,15 @@ class CPLEXDirect(OptSolver):
         else:
             labeler = NumericLabeler('x')
         symbol_map = SymbolMap()
-        pyomo_instance.solutions.add_symbol_map(symbol_map)
         self._smap_id = id(symbol_map)
+        if isinstance(pyomo_instance, IBlockStorage):
+            # BIG HACK (see pyomo.core.kernel write function)
+            if not hasattr(pyomo_instance, "._symbol_maps"):
+                setattr(pyomo_instance, "._symbol_maps", {})
+            getattr(pyomo_instance,
+                    "._symbol_maps")[self._smap_id] = symbol_map
+        else:
+            pyomo_instance.solutions.add_symbol_map(symbol_map)
 
         # we use this when iterating over the constraints because it
         # will have a much smaller hash table, we also use this for
@@ -407,11 +419,11 @@ class CPLEXDirect(OptSolver):
             var_names.append(symbol_map.getSymbol( var, labeler ))
             var_symbol_pairs.append((var, varname))
 
-            if (var.lb is None) or (var.lb == -infinity):
+            if not var.has_lb():
                 var_lbs.append(-CPLEXDirect._cplex_module.infinity)
             else:
                 var_lbs.append(value(var.lb))
-            if (var.ub is None) or (var.ub == infinity):
+            if not var.has_ub():
                 var_ubs.append(CPLEXDirect._cplex_module.infinity)
             else:
                 var_ubs.append(value(var.ub))
@@ -509,7 +521,8 @@ class CPLEXDirect(OptSolver):
                     obj_repn = block_canonical_repn[obj_data]
 
                 if (isinstance(obj_repn, LinearCanonicalRepn) and \
-                    (obj_repn.linear == None)) or \
+                    ((obj_repn.linear is None) or \
+                     (len(obj_repn.linear) == 0))) or \
                     canonical_is_constant(obj_repn):
                     print("Warning: Constant objective detected, replacing " + \
                           "with a placeholder to prevent solver failure.")
@@ -572,12 +585,15 @@ class CPLEXDirect(OptSolver):
                                                     active=True,
                                                     descend_into=False):
 
-                if (con.lower is None) and \
-                   (con.upper is None):
+                if (not con.has_lb()) and \
+                   (not con.has_ub()):
+                    assert not con.equality
                     continue  # not binding at all, don't bother
 
                 con_repn = None
-                if isinstance(con, LinearCanonicalRepn):
+                if con._linear_canonical_form:
+                    con_repn = con.canonical_form()
+                elif isinstance(con, LinearCanonicalRepn):
                     con_repn = con
                 else:
                     if gen_con_canonical_repn:
@@ -593,8 +609,9 @@ class CPLEXDirect(OptSolver):
                 # possible that the body of the constraint consists of only a
                 # constant, in which case the "variable" of
                 if isinstance(con_repn, LinearCanonicalRepn):
-                    if (con_repn.linear is None) and \
-                       self._skip_trivial_constraints:
+                    if self._skip_trivial_constraints and \
+                       ((con_repn.linear is None) or \
+                        (len(con_repn.linear) == 0)):
                        continue
                 else:
                     # we shouldn't come across a constant canonical repn
@@ -635,17 +652,18 @@ class CPLEXDirect(OptSolver):
                         qsenses.append('E')
                         qrhss.append(self._get_bound(con.lower) - offset)
 
-                    elif (con.lower is not None) and (con.upper is not None):
+                    elif con.has_lb() and con.has_ub():
                         raise RuntimeError(
                             "The CPLEXDirect plugin can not translate range "
                             "constraints containing quadratic expressions.")
 
-                    elif con.lower is not None:
-                        assert con.upper is None
+                    elif con.has_lb():
+                        assert not con.has_ub()
                         qsenses.append('G')
                         qrhss.append(self._get_bound(con.lower) - offset)
 
                     else:
+                        assert con.has_ub()
                         qsenses.append('L')
                         qrhss.append(self._get_bound(con.upper) - offset)
 
@@ -662,7 +680,7 @@ class CPLEXDirect(OptSolver):
                         rhss.append(self._get_bound(con.lower) - offset)
                         range_values.append(0.0)
 
-                    elif (con.lower is not None) and (con.upper is not None):
+                    elif con.has_lb() and con.has_ub():
                         # ranged constraint.
                         senses.append('R')
                         lower_bound = self._get_bound(con.lower) - offset
@@ -670,12 +688,13 @@ class CPLEXDirect(OptSolver):
                         rhss.append(lower_bound)
                         range_values.append(upper_bound - lower_bound)
 
-                    elif con.lower is not None:
+                    elif con.has_lb():
                         senses.append('G')
                         rhss.append(self._get_bound(con.lower) - offset)
                         range_values.append(0.0)
 
                     else:
+                        assert con.has_ub()
                         senses.append('L')
                         rhss.append(self._get_bound(con.upper) - offset)
                         range_values.append(0.0)
@@ -852,7 +871,7 @@ class CPLEXDirect(OptSolver):
             raise ValueError(msg % len(args))
 
         model = args[ 0 ]
-        if not isinstance(model, Model):
+        if not isinstance(model, (Model, IBlockStorage)):
             msg = "The problem instance supplied to the CPLEXDirect plugin " \
                   "method '_presolve' must be of type 'Model' - "\
                   "interface does not currently support file names"
@@ -866,10 +885,14 @@ class CPLEXDirect(OptSolver):
         # below), relies on a "clean" symbol map
         vars_to_delete = set(self._variable_symbol_map.byObject.keys()) - \
                          self._referenced_variable_ids
-        sm_byObject = model.solutions.symbol_map[self._smap_id].byObject
-        sm_bySymbol = model.solutions.symbol_map[self._smap_id].bySymbol
-        #sm_bySymbol = self._symbol_map.bySymbol
-        assert(len(model.solutions.symbol_map[self._smap_id].aliases) == 0)
+        if isinstance(model, IBlockStorage):
+            symbol_map = getattr(model,
+                                 "._symbol_maps")[self._smap_id]
+        else:
+            symbol_map = model.solutions.symbol_map[self._smap_id]
+        sm_byObject = symbol_map.byObject
+        sm_bySymbol = symbol_map.bySymbol
+        assert len(symbol_map.aliases) == 0
         var_sm_byObject = self._variable_symbol_map.byObject
         var_sm_bySymbol = self._variable_symbol_map.bySymbol
         for varid in vars_to_delete:
@@ -1054,11 +1077,14 @@ class CPLEXDirect(OptSolver):
         if soln_status in [1, 101, 102]:
             results.solver.termination_condition = TerminationCondition.optimal
             soln.status = SolutionStatus.optimal
-        elif soln_status in [2, 4, 118, 119]:
-            # Note: soln_status of 4 means infeasible or unbounded
-            #       and 119 means MIP infeasible or unbounded
+        elif soln_status in [2, 118]:
             results.solver.termination_condition = TerminationCondition.unbounded
             soln.status = SolutionStatus.unbounded
+        elif soln_status in [4, 119]:
+            # Note: soln_status of 4 means infeasible or unbounded
+            #       and 119 means MIP infeasible or unbounded
+            results.solver.termination_condition = TerminationCondition.infeasibleOrUnbounded
+            soln.status = SolutionStatus.unsure
         elif soln_status in [3, 103]:
             results.solver.termination_condition = TerminationCondition.infeasible
             soln.status = SolutionStatus.infeasible
@@ -1146,7 +1172,13 @@ class CPLEXDirect(OptSolver):
                     soln_constraint[q_constraint_names[i]] = \
                         {"Slack" : slack_values[i]}
 
-            byObject = self._instance.solutions.symbol_map[self._smap_id].byObject
+            if isinstance(self._instance, IBlockStorage):
+                symbol_map = getattr(self._instance,
+                                     "._symbol_maps")[self._smap_id]
+            else:
+                symbol_map = self._instance.solutions.\
+                             symbol_map[self._smap_id]
+            byObject = symbol_map.byObject
             referenced_varnames = set(byObject[varid]
                                       for varid in self._referenced_variable_ids)
             names_to_delete = set(soln_variable.keys())-referenced_varnames
