@@ -17,7 +17,6 @@ import math
 
 import pyutilib.services
 from pyutilib.misc import Bunch, Options
-from pyutilib.math import infinity
 
 import pyomo.util.plugin
 from pyomo.opt.base import *
@@ -33,6 +32,8 @@ from pyomo.core.base import (SymbolMap,
 from pyomo.repn import generate_canonical_repn
 from pyomo.solvers import wrappers
 
+from pyomo.core.kernel.component_block import IBlockStorage
+
 from six import itervalues, iterkeys, iteritems, advance_iterator
 from six.moves import xrange
 from pyomo.solvers.plugins.solvers.CPLEXDirect import (CPLEXDirect,
@@ -110,12 +111,12 @@ class CPLEXPersistent(CPLEXDirect, PersistentSolver):
                 # compiled out of any description of the constraints
                 return
             else:
-                if var_data.lb is None:
+                if not var_data.has_lb():
                     var_lb = -CPLEXDirect._cplex_module.infinity
                 else:
                     var_lb = value(var_data.lb)
 
-                if var_data.ub is None:
+                if not var_data.has_ub():
                     var_ub = CPLEXDirect._cplex_module.infinity
                 else:
                     var_ub= value(var_data.ub)
@@ -159,6 +160,8 @@ class CPLEXPersistent(CPLEXDirect, PersistentSolver):
 
         cplex_instance = self._active_cplex_instance
 
+        self._has_quadratic_objective = False
+
         cntr = 0
         for block in pyomo_instance.block_data_objects(active=True):
             gen_obj_canonical_repn = \
@@ -197,7 +200,8 @@ class CPLEXPersistent(CPLEXDirect, PersistentSolver):
                     obj_repn = block_canonical_repn[obj_data]
 
                 if (isinstance(obj_repn, LinearCanonicalRepn) and \
-                    (obj_repn.linear == None)) or \
+                    ((obj_repn.linear == None) or \
+                     (len(obj_repn.linear) == 0))) or \
                     canonical_is_constant(obj_repn):
                     print("Warning: Constant objective detected, replacing "
                           "with a placeholder to prevent solver failure.")
@@ -270,7 +274,6 @@ class CPLEXPersistent(CPLEXDirect, PersistentSolver):
 
         self._has_quadratic_constraints = False
         self._has_quadratic_objective = False
-        used_sos_constraints = False
 
         self._active_cplex_instance = CPLEXDirect._cplex_module.Cplex()
 
@@ -281,7 +284,14 @@ class CPLEXPersistent(CPLEXDirect, PersistentSolver):
 
         self._symbol_map = SymbolMap()
         self._instance = pyomo_instance
-        pyomo_instance.solutions.add_symbol_map(self._symbol_map)
+        if isinstance(pyomo_instance, IBlockStorage):
+            # BIG HACK
+            if not hasattr(pyomo_instance, "._symbol_maps"):
+                setattr(pyomo_instance, "._symbol_maps", {})
+            getattr(pyomo_instance, "._symbol_maps")[id(self._symbol_map)] = \
+                self._symbol_map
+        else:
+            pyomo_instance.solutions.add_symbol_map(self._symbol_map)
         self._smap_id = id(self._symbol_map)
 
         # we use this when iterating over the constraints because it
@@ -292,9 +302,10 @@ class CPLEXPersistent(CPLEXDirect, PersistentSolver):
 
         # cplex wants the caller to set the problem type, which is (for
         # current purposes) strictly based on variable type counts.
-        num_binary_variables = 0
-        num_integer_variables = 0
-        num_continuous_variables = 0
+        self._num_binary_variables = 0
+        self._num_integer_variables = 0
+        self._num_continuous_variables = 0
+        self._used_sos_constraints = False
 
         #############################################
         # populate the variables in the cplex model #
@@ -328,25 +339,25 @@ class CPLEXPersistent(CPLEXDirect, PersistentSolver):
 
             self._cplex_variable_ids[var_name] = len(self._cplex_variable_ids)
 
-            if (var_data.lb is None) or (var_data.lb == -infinity):
+            if not var_data.has_lb():
                 var_lbs.append(-CPLEXDirect._cplex_module.infinity)
             else:
                 var_lbs.append(value(var_data.lb))
 
-            if (var_data.ub is None) or (var_data.ub == infinity):
+            if not var_data.has_ub():
                 var_ubs.append(CPLEXDirect._cplex_module.infinity)
             else:
                 var_ubs.append(value(var_data.ub))
 
             if var_data.is_integer():
                 var_types.append(self._active_cplex_instance.variables.type.integer)
-                num_integer_variables += 1
+                self._num_integer_variables += 1
             elif var_data.is_binary():
                 var_types.append(self._active_cplex_instance.variables.type.binary)
-                num_binary_variables += 1
+                self._num_binary_variables += 1
             elif var_data.is_continuous():
                 var_types.append(self._active_cplex_instance.variables.type.continuous)
-                num_continuous_variables += 1
+                self._num_continuous_variables += 1
             else:
                 raise TypeError("Invalid domain type for variable with name '%s'. "
                                 "Variable is not continuous, integer, or binary.")
@@ -394,12 +405,15 @@ class CPLEXPersistent(CPLEXDirect, PersistentSolver):
                                                     active=True,
                                                     descend_into=False):
 
-                if (con.lower is None) and \
-                   (con.upper is None):
+                if (not con.has_lb()) and \
+                   (not con.has_ub()):
+                    assert not con.equality
                     continue  # not binding at all, don't bother
 
                 con_repn = None
-                if isinstance(con, LinearCanonicalRepn):
+                if con._linear_canonical_form:
+                    con_repn = con.canonical_form()
+                elif isinstance(con, LinearCanonicalRepn):
                     con_repn = con
                 else:
                     if gen_con_canonical_repn:
@@ -415,8 +429,9 @@ class CPLEXPersistent(CPLEXDirect, PersistentSolver):
                 # possible that the body of the constraint consists of only a
                 # constant, in which case the "variable" of
                 if isinstance(con_repn, LinearCanonicalRepn):
-                    if (con_repn.linear is None) and \
-                       self._skip_trivial_constraints:
+                    if self._skip_trivial_constraints and \
+                       ((con_repn.linear is None) or \
+                        (len(con_repn.linear) == 0)):
                        continue
                 else:
                     # we shouldn't come across a constant canonical repn
@@ -458,17 +473,19 @@ class CPLEXPersistent(CPLEXDirect, PersistentSolver):
                         qsenses.append('E')
                         qrhss.append(self._get_bound(con.lower) - offset)
 
-                    elif (con.lower is not None) and (con.upper is not None):
+                    elif con.has_lb() and con.has_ub():
+
                         raise RuntimeError(
                             "The CPLEXDirect plugin can not translate range "
                             "constraints containing quadratic expressions.")
 
-                    elif con.lower is not None:
-                        assert con.upper is None
+                    elif con.has_lb():
+                        assert not con.has_ub()
                         qsenses.append('G')
                         qrhss.append(self._get_bound(con.lower) - offset)
 
                     else:
+                        assert con.has_ub()
                         qsenses.append('L')
                         qrhss.append(self._get_bound(con.upper) - offset)
 
@@ -485,7 +502,7 @@ class CPLEXPersistent(CPLEXDirect, PersistentSolver):
                         rhss.append(self._get_bound(con.lower) - offset)
                         range_values.append(0.0)
 
-                    elif (con.lower is not None) and (con.upper is not None):
+                    elif con.has_lb() and con.has_ub():
                         # ranged constraint.
                         senses.append('R')
                         lower_bound = self._get_bound(con.lower) - offset
@@ -493,12 +510,13 @@ class CPLEXPersistent(CPLEXDirect, PersistentSolver):
                         rhss.append(lower_bound)
                         range_values.append(upper_bound - lower_bound)
 
-                    elif con.lower is not None:
+                    elif con.has_lb():
                         senses.append('G')
                         rhss.append(self._get_bound(con.lower) - offset)
                         range_values.append(0.0)
 
                     else:
+                        assert con.has_ub()
                         senses.append('L')
                         rhss.append(self._get_bound(con.upper) - offset)
                         range_values.append(0.0)
@@ -535,7 +553,7 @@ class CPLEXPersistent(CPLEXDirect, PersistentSolver):
                                        SOS = [modelSOS.varnames[key],
                                               modelSOS.weights[key]])
                 self._referenced_variable_ids.update(modelSOS.varids[key])
-            used_sos_constraints = True
+            self._used_sos_constraints = True
 
         self._active_cplex_instance.linear_constraints.add(
             lin_expr=expressions,
@@ -558,49 +576,6 @@ class CPLEXPersistent(CPLEXDirect, PersistentSolver):
 
         self.compile_objective(pyomo_instance)
 
-        ################################################
-        # populate the problem type in the cplex model #
-        ################################################
-
-        # This gets rid of the annoying "Freeing MIP data." message.
-        def _filter_freeing_mip_data(val):
-            if val.strip() == 'Freeing MIP data.':
-                return ""
-            return val
-        self._active_cplex_instance.set_warning_stream(sys.stderr,
-                                                       fn=_filter_freeing_mip_data)
-
-        if (self._has_quadratic_objective is True) or \
-           (self._has_quadratic_constraints is True):
-            if (num_integer_variables > 0) or \
-               (num_binary_variables > 0) or \
-               (used_sos_constraints):
-                if self._has_quadratic_constraints is True:
-                    self._active_cplex_instance.set_problem_type(
-                        self._active_cplex_instance.problem_type.MIQCP)
-                else:
-                    self._active_cplex_instance.set_problem_type(
-                        self._active_cplex_instance.problem_type.MIQP)
-            else:
-                if self._has_quadratic_constraints is True:
-                    self._active_cplex_instance.set_problem_type(
-                        self._active_cplex_instance.problem_type.QCP)
-                else:
-                    self._active_cplex_instance.set_problem_type(
-                        self._active_cplex_instance.problem_type.QP)
-        elif (num_integer_variables > 0) or \
-             (num_binary_variables > 0) or \
-             (used_sos_constraints):
-            self._active_cplex_instance.set_problem_type(
-                self._active_cplex_instance.problem_type.MILP)
-        else:
-            self._active_cplex_instance.set_problem_type(
-                self._active_cplex_instance.problem_type.LP)
-
-        # restore the warning stream without our filter function
-        self._active_cplex_instance.set_warning_stream(sys.stderr)
-
-
     #
     # simple method to query whether a Pyomo instance has already been
     # compiled.
@@ -667,8 +642,58 @@ class CPLEXPersistent(CPLEXDirect, PersistentSolver):
             assert self._skip_trivial_constraints == \
                 kwds["skip_trivial_constraints"]
 
-        if self._smap_id not in self._instance.solutions.symbol_map:
-            self._instance.solutions.add_symbol_map(self._symbol_map)
+        if isinstance(self._instance, IBlockStorage):
+            # BIG HACK
+            if not hasattr(self._instance, "._symbol_maps"):
+                setattr(self._instance, "._symbol_maps", {})
+            getattr(self._instance, "._symbol_maps")[id(self._symbol_map)] = \
+                self._symbol_map
+        else:
+            if self._smap_id not in self._instance.solutions.symbol_map:
+                self._instance.solutions.add_symbol_map(self._symbol_map)
+
+
+        ################################################
+        # populate the problem type in the cplex model #
+        ################################################
+
+        # This gets rid of the annoying "Freeing MIP data." message.
+        def _filter_freeing_mip_data(val):
+            if val.strip() == 'Freeing MIP data.':
+                return ""
+            return val
+        self._active_cplex_instance.set_warning_stream(sys.stderr,
+                                                       fn=_filter_freeing_mip_data)
+
+        if (self._has_quadratic_objective is True) or \
+           (self._has_quadratic_constraints is True):
+            if (self._num_integer_variables > 0) or \
+               (self._num_binary_variables > 0) or \
+               (self._used_sos_constraints):
+                if self._has_quadratic_constraints is True:
+                    self._active_cplex_instance.set_problem_type(
+                        self._active_cplex_instance.problem_type.MIQCP)
+                else:
+                    self._active_cplex_instance.set_problem_type(
+                        self._active_cplex_instance.problem_type.MIQP)
+            else:
+                if self._has_quadratic_constraints is True:
+                    self._active_cplex_instance.set_problem_type(
+                        self._active_cplex_instance.problem_type.QCP)
+                else:
+                    self._active_cplex_instance.set_problem_type(
+                        self._active_cplex_instance.problem_type.QP)
+        elif (self._num_integer_variables > 0) or \
+             (self._num_binary_variables > 0) or \
+             (self._used_sos_constraints):
+            self._active_cplex_instance.set_problem_type(
+                self._active_cplex_instance.problem_type.MILP)
+        else:
+            self._active_cplex_instance.set_problem_type(
+                self._active_cplex_instance.problem_type.LP)
+
+        # restore the warning stream without our filter function
+        self._active_cplex_instance.set_warning_stream(sys.stderr)
 
         CPLEXDirect._presolve(self, *args, **kwds)
 
