@@ -23,6 +23,7 @@ from pyomo.opt.base import *
 from pyomo.opt.base.solvers import _extract_version
 from pyomo.opt.results import *
 from pyomo.opt.solver import *
+from pyomo.core.kernel.component_block import IBlockStorage
 
 logger = logging.getLogger('pyomo.solvers')
 
@@ -126,9 +127,18 @@ class GUROBISHELL(ILMLicensedSystemCallSolver):
         except OSError:
             rc = 1
         if rc:
-            return False
-        else:
-            return True
+            #
+            # Try the --status flag if --license is not available
+            #
+            try:
+                rc = subprocess.call([executable, "--status"],
+                                 stdout=subprocess.PIPE,
+                                 stderr=subprocess.STDOUT)
+            except OSError:
+                rc = 1
+            if rc:
+                return False
+        return True
 
     def _default_results_format(self, prob_format):
         return ResultsFormat.soln
@@ -149,8 +159,6 @@ class GUROBISHELL(ILMLicensedSystemCallSolver):
 
         from pyomo.core.base import Var
 
-        mst_file = open(self._warm_start_file_name, 'w')
-
         # for each variable in the symbol_map, add a child to the
         # variables element.  Both continuous and discrete are accepted
         # (and required, depending on other options), according to the
@@ -158,14 +166,19 @@ class GUROBISHELL(ILMLicensedSystemCallSolver):
         # **Note**: This assumes that the symbol_map is "clean", i.e.,
         # contains only references to the variables encountered in constraints
         output_index = 0
-        smap = instance.solutions.symbol_map[self._smap_id]
+        if isinstance(instance, IBlockStorage):
+            smap = getattr(instance,"._symbol_maps")\
+                   [self._smap_id]
+        else:
+            smap = instance.solutions.symbol_map[self._smap_id]
         byObject = smap.byObject
-        for vdata in instance.component_data_objects(Var, active=True):
-            if (vdata.value is not None) and (id(vdata) in byObject):
-                name = byObject[id(vdata)]
-                mst_file.write("%s %s\n" % (name, str(vdata.value)))
-
-        mst_file.close()
+        with open(self._warm_start_file_name, 'w') as mst_file:
+            for vdata in instance.component_data_objects(Var, active=True):
+                if (vdata.value is not None) and \
+                   (id(vdata) in byObject):
+                    name = byObject[id(vdata)]
+                    mst_file.write("%s %s\n"
+                                   % (name, vdata.value))
 
     # over-ride presolve to extract the warm-start keyword, if specified.
     def _presolve(self, *args, **kwds):
@@ -417,11 +430,13 @@ class GUROBISHELL(ILMLicensedSystemCallSolver):
                     elif (tokens[0] == 'gap'):
                         soln.gap = float(tokens[1])
                     elif (tokens[0] == 'objective'):
-                        soln.objective['__default_objective__'] = {'Value': float(tokens[1])}
-                        if results.problem.sense == ProblemSense.minimize:
-                            results.problem.upper_bound = float(tokens[1])
-                        else:
-                            results.problem.lower_bound = float(tokens[1])
+                        if tokens[1].strip() != 'None':
+                            soln.objective['__default_objective__'] = \
+                                {'Value': float(tokens[1])}
+                            if results.problem.sense == ProblemSense.minimize:
+                                results.problem.upper_bound = float(tokens[1])
+                            else:
+                                results.problem.lower_bound = float(tokens[1])
                     elif (tokens[0] == 'constraintdual'):
                         name = tokens[1]
                         if name != "c_e_ONE_VAR_CONSTANT":
@@ -484,7 +499,7 @@ class GUROBISHELL(ILMLicensedSystemCallSolver):
             else:
                 soln_constraints.setdefault('r_l_'+key,{})["Slack"] = us    # Use the same key
 
-        if solution_seen is True:
+        if solution_seen:
             results.solution.insert(soln)
 
     def _postsolve(self):
